import bb.cascades 1.2

Container {    
    id: downloadListItem
    objectName: "downloadListItem"
    maxHeight: 102
    topPadding: 10
    bottomPadding: 10
    
    minHeight: maxHeight
    preferredHeight: maxHeight
    
    property alias leftImageSource: leftButton.defaultImageSource
    property alias rightImageSource: rightButton.defaultImageSource 
    property alias leftBottomLabel: bottomLabelLeft.text
    property alias rightBottomLabel: bottomLabelRight.text
    property alias launchButtonText: openButton.text
    property alias otherDownloads: otherDownloadsLabel.text
    
    property string leftButtonName: qsTr("Pause")
    property string rightButtonName: qsTr("Resume")

    property bool iconVisible: false
    property bool nameVisible: true
    
    property bool leftButtonVisible: true
    property bool rightButtonVisible: false
    property bool openButtonVisible: false
    
    
    
    signal leftClicked
    signal rightClicked
    signal openClicked
    
    signal progressClicked
    
    /**
     * How to use this QML:
     * Use a controller class written in C++.
     * -Use Find Child to locate controls.
     * -Use set text of the topLabel and bottomLabelLeft (and bottomLabelRight if needed, it is not visible by default)
     * -Set the Image Source of the leftButton and rightButton to represent the appropriate action.
     * -Set the visiblility of leftButton and rightButtonContainer to represent the appropriate actions visible in the
     * present state.
     * -Set the visiblility of launchButtonContainer to represent the appropriate visual state.
     * -Set the text of the launchButton to a localized string.
     * -Connect the touch signals from the buttons to the appropriate slot on your controller.
     *
     */
        layout: StackLayout {
            orientation: LayoutOrientation.LeftToRight
        }
        //maxHeight: 130
        //minHeight: 130
        //preferredHeight: 130
        leftPadding: 10
        rightPadding: 20
        
        Container {
            onTouch: {
                if (event.isUp()) {
                    progressClicked();
                }
            }
            
            //maxWidth: 614
            
            topPadding: 2
            leftPadding: 10
            
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Center            
            layoutProperties: StackLayoutProperties {
                spaceQuota: 1
            }

			accessibility: CustomA11yObject {
		        role: A11yRole.Status
		        name: Math.floor(progress.value / progress.toValue * 100) + "%"
				description: bottomLabelLeft.text + " : " + bottomLabelRight.text
	    	}
            
            Label {
                id: otherDownloadsLabel
                objectName: "otherDownloadsLabel"                
                visible: text.length > 0
                //text: "Stupipd stupid autom complete"
                horizontalAlignment: HorizontalAlignment.Left
                verticalAlignment: VerticalAlignment.Top                                
                textStyle {
                    fontSize: FontSize.Medium             
                }
                bottomMargin: 0
				accessibilityMode: A11yMode.Collapsed
            }
            ProgressIndicator {
                preferredWidth: maxWidth
                id: progress
                objectName: "progress"
                visible: true
                fromValue: 0.0
                toValue: 100.0
                bottomMargin: 7                
				accessibilityMode: A11yMode.Collapsed
            }
            
            Container {
                //leftPadding: 4
                rightPadding: 4
                layout: StackLayout {
                    orientation: LayoutOrientation.LeftToRight
                }
                horizontalAlignment: HorizontalAlignment.Fill
                accessibilityMode: A11yMode.Collapsed

                Label {
                    horizontalAlignment: HorizontalAlignment.Left
                    verticalAlignment: VerticalAlignment.Top
                    id: bottomLabelLeft
                    objectName: "bottomLabelLeft"
                    //text: "Left"
                    textStyle {
                        //base: SystemDefaults.TextStyles.BodyText
                        fontSize: FontSize.Small
                        color: Color.create(FontSecondaryColor)
                    }
                }
                Label {
                    layoutProperties: StackLayoutProperties {
                        spaceQuota: 1
                    }
                    id: bottomLabelRight
                    objectName: "bottomLabelRight"
                    visible: text.length > 0
                    
                    horizontalAlignment: HorizontalAlignment.Right
                    verticalAlignment: VerticalAlignment.Top
                    //text: "Right"
                    textStyle {
                        color: Color.create(FontSecondaryColor)
                        textAlign: TextAlign.Right
                        fontSize: FontSize.Small
                    }
                }                
            }
        }
        
        ImageButton {
            visible: leftButtonVisible
            id: leftButton
            objectName: "leftButton"
            defaultImageSource: "asset:///images/action_icons/ic_pause.png"
            minWidth: 81
            minHeight: 81
            horizontalAlignment: HorizontalAlignment.Left
            verticalAlignment: VerticalAlignment.Center
            onClicked: {
                downloadListItem.leftClicked();
            }
            accessibility.name: leftButtonName
        }
        ImageButton {
            visible: rightButtonVisible
            minWidth: 81
            minHeight: 81
            id: rightButton
            objectName: "rightButton"
            defaultImageSource: "asset:///images/action_icons/ic_resume.png"
            horizontalAlignment: HorizontalAlignment.Right
            verticalAlignment: VerticalAlignment.Center
            onClicked: {
                downloadListItem.rightClicked();
            }
            accessibility.name: leftButtonName
        }
        Button{
            visible: openButtonVisible
            id: openButton
            objectName: "openButton"
            text: qsTr("Open", "Text for opening content upon download completion")
            verticalAlignment: VerticalAlignment.Center
            horizontalAlignment: HorizontalAlignment.Right
            preferredWidth: 81            
            //            layoutProperties: StackLayoutProperties {
            //                spaceQuota: 1
            //            }
            onClicked: {
                openClicked();
            }
        }

}
