import bb.cascades 1.2

Container {
    id: contentListItem
    objectName: "contentListItem"
    property alias name: displayname.text//: "Cut the Rope"
    property alias subtitle: subtitle.text//: "Vendor Name"
    property alias price: price.text
    property string origPrice: "$0.99"
    property string promoPrice: "Not Free"
    property string description;
    property int starRating: -1
    property int reviewCount: -1
    property string iconImageSource: "asset:///images/loading_placeholder.amd"
    property bool showRating: true
    property bool showIcon: true
    property variant priceColor: Color.create("#FF80FF00")
    property variant selectedColor: Color.create("#E400A8DF")
    
    property bool aspectBoxArt: false
    property int iconWidth: StackIconWidth
    property int iconHeight: StackIconWidth
        attachedObjects: [
            TextStyleDefinition {
                id: titleText
                fontSize: FontSize.Medium
            },
            TextStyleDefinition {
                id: subtitleText
                color: Color.create(FontSecondaryColor)
                fontSize: FontSize.XSmall
            },
            TextStyleDefinition {
                id: priceText
                color: Color.create(FontSecondaryColor)
                fontSize: FontSize.Small
                textAlign: TextAlign.Right
            }        
        ]
    
    layout: DockLayout {
    }
    
    onAspectBoxArtChanged: {
        if(aspectBoxArt){
            iconHeight = iconWidth * 1.36           
        }else{
            iconHeight = iconWidth;     
        }
    }
    Container {
        Container {
            objectName: "item-" + name + "-" //jwillis
            layout: StackLayout {
                orientation: LayoutOrientation.LeftToRight
            }
            topPadding: 10
            bottomPadding: 10
            leftPadding: 20
            rightPadding: 20
            horizontalAlignment: HorizontalAlignment.Fill
                        
            accessibility {
                name: displayname.text + " : " + ((promoPrice == "Not Free") ? price.text : 
                		qsTr("Original") + " : " + origPrice + " : " + qsTr("Now") + " : " + promoPrice)
                description: subtitle.text + " : " + starRating.accessibility.name
            }
            
            ImageView {
                visible: showIcon
                id: icon
                objectName: "icon"
                imageSource: contentListItem.iconImageSource
                //scalingMethod: ScalingMethod.AspectFit
                preferredWidth: iconWidth
                preferredHeight: iconHeight
                verticalAlignment: VerticalAlignment.Center
                horizontalAlignment: HorizontalAlignment.Center
                accessibilityMode: A11yMode.Collapsed
            }
            
            Container {
                id: bottomRowContainer
                objectName: "bottomRowContainer"
                bottomPadding: 10
                rightMargin: 0
                leftMargin: 10
                verticalAlignment: VerticalAlignment.Center
                horizontalAlignment: HorizontalAlignment.Fill
                accessibilityMode: A11yMode.Collapsed
                layoutProperties: StackLayoutProperties {
                    spaceQuota: 1
                }
                leftPadding: 4
                Label {
                    id: displayname                    
                    objectName: "name" //jwillis
                    bottomMargin: 0
                    topMargin: 0
                    textStyle.base: titleText.style
                }
                Label {
                    id: subtitle
                    visible: text.length > 0                    
                    objectName: "subtitle"
                    topMargin: 4
                    bottomMargin: 6
                    textStyle.base: subtitleText.style
                }
                Container {
                    layout: StackLayout {
                        orientation: LayoutOrientation.LeftToRight
                    }
                    topMargin: 0
                    topPadding: 0
                    bottomMargin: 0
                    bottomPadding: 0
                    leftMargin: 0
                    leftPadding: 0
                    rightMargin: 0
                    rightPadding: 0
                    
	                StarRating {
	                    //topMargin: 0
	                    visible: showRating
	                    rating: contentListItem.starRating
	                    reviewCount: contentListItem.reviewCount
	                    id: starRating
	                    objectName: "starRating"
	                    verticalAlignment: VerticalAlignment.Center
	                }
	                
	                Container {
	                    id: badgeContainer
	                    objectName: "badgeContainer"
	                    layout: StackLayout {
	                        orientation: LayoutOrientation.LeftToRight
	                    }
	                    topMargin: 0
	                    topPadding: 0
	                    bottomMargin: 0
	                    bottomPadding: 0
	                    layoutProperties: StackLayoutProperties {
                            spaceQuota: 1
                        }
	                    visible: false
	                }
                }
                Label {
                    id: description
                    visible: text.length > 0                    
                    objectName: "description"
                    topMargin: 0
                    bottomMargin: 0
                }
                ImageView{
                    id: rating
                    objectName: "rating"
                    visible: false                                        
                    scalingMethod: ScalingMethod.AspectFit
                    preferredHeight: RatingIconHeight
                    minHeight: RatingIconHeight
                    maxHeight: RatingIconHeight
                }
            }
            Container {
                leftPadding: 30
                verticalAlignment: VerticalAlignment.Center
                accessibilityMode: A11yMode.Collapsed
                Label {
                    id: price
                    //text: contentListItem.price
                    //text: "<html><head><style>body{text-align: right}</style></head><body><span style=\"font-size: 6;color:lightgrey;font-weight:500;text-decoration:line-through\">$0.99</span><br/>Free</body></html>"
                    multiline: true
                    objectName: "price" //jwillis
                    horizontalAlignment: HorizontalAlignment.Right
                    verticalAlignment: VerticalAlignment.Center
                    bottomMargin: 0
                    topMargin: 0
                    leftMargin: 12
                    textStyle.base: priceText.style
                }
            }
        }
    }    

}
