import bb.cascades 1.4

Container {
    id: detailsHeader
    objectName: "detailsHeader"
    
    property string title; //: "Journey 2: The Mysterious Island"
    property string subtitle; //: "Subtitle"
    property string subtitle_a11y; //: "accessibility subtitle"
    property bool focus_subtitle: false
    property string description; //: '<html><head><style>a:link{color:#ff00a8df;text-decoration:none;font-weight:500} body{font-size:7.8} span.[prefix]{font-size: 7.4;color: grey;font-weight:300}</style></head><body><span style="font-size:7;color:lightgray">Released 1971</span><br/><span style="font-size:7;color:lightgray">2 hour 17 min</span><br/><span style="font-size:7;color:lightgray">48 hour rental*</span></body></html>'
    property string sizeLabel; //: "60 MB"
    property int reviewCount: -1
    property int rating: -1
    property bool showContentRating: false
    property alias imageSource: icon.imageSource
    property alias contentRatingImageSource: contentRating.imageSource
    property bool showClosedCaptionIcon: false
    property bool explicit: false
    property bool aspectBoxArt: false
    property int iconMinSize: DisplayIsHD ? 300 : 150
    property int boxArtMinSize: DisplayIsHD ? 490 : 245

    onEnabledChanged: {
        buttonContainer.enabled = detailsHeader.enabled;
    }

    onCreationCompleted: {
        locallyFocused = true
    }

    attachedObjects: [
        TextStyleDefinition {
            id: titleWhite
            fontSize: FontSize.Medium
            fontWeight: FontWeight.W500
        },
        TextStyleDefinition {
            id: subtitleLightGray
            color: Color.create(FontSecondaryColor)
            fontSize: DisplayIsHD ? FontSize.Small : FontSize.XSmall
        }
    ]

    onAspectBoxArtChanged: {
        if (aspectBoxArt) {
            icon.minHeight = boxArtMinSize
            icon.minWidth = boxArtMinSize * 0.73
        } else {
            icon.minHeight = iconMinSize
            icon.minWidth = iconMinSize
        }
    }
    Container {
        minHeight: 174
        //        preferredHeight: minHeight
        //        maxHeight: minHeight
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        layout: StackLayout {
            orientation: LayoutOrientation.LeftToRight
        }
        leftPadding: 10
        rightPadding: 10
        topPadding: 10
        bottomPadding: 10

        ImageView {
            id: icon
            objectName: "icon"
            imageSource: "asset:///images/loading_placeholder.amd"

            minWidth: iconMinSize
            minHeight: iconMinSize
            preferredHeight: minWidth
            preferredWidth: minHeight
            scalingMethod: ScalingMethod.AspectFill
            verticalAlignment: VerticalAlignment.Top
            accessibilityMode: A11yMode.Collapsed
            implicitLayoutAnimationsEnabled: false
            attachedObjects: [
                ImplicitAnimationController {
                    enabled: false
                }
            ]

        }


        Container {
            rightPadding: 0
            leftPadding: 8
            minHeight: icon.minHeight - 46
            preferredHeight: icon.minHeight - 46
            
            layout: StackLayout {
                orientation: LayoutOrientation.LeftToRight
            }
            
            Container {
                rightMargin: 15
                
               	accessibility.name: (detailsHeader.title.length > 0 ? detailsHeader.title + " : " : "") + 
                                    (detailsHeader.subtitle_a11y.length > 0 ? detailsHeader.subtitle_a11y + " : " : "") + 
               						(starRating.accessibility.name.length > 0 ? starRating.accessibility.name : "");
               	
               	accessibility.description: 	(detailsHeader.sizeLabel.length > 0 ? detailsHeader.sizeLabel + " : " : "") + 
               								(detailsHeader.description.length > 0 ? detailsHeader.description + " : " : "") + 
               								(detailsHeader.showClosedCaptionIcon == true ? qsTr("Closed captioning available.") : "") + 
               								(detailsHeader.explicit ? " : " + qsTr("explicit") : "" )
               	
                layout: StackLayout {
                    orientation: LayoutOrientation.TopToBottom
                }
                layoutProperties: StackLayoutProperties {
                    spaceQuota: 1
                }
	            Label {
	                id: name
	                objectName: "name"
	                multiline: true
	                autoSize.maxLineCount: 2
	                text: detailsHeader.title
	                textStyle.base: titleWhite.style
	                topMargin: 0
	                bottomMargin: 0
	                accessibilityMode: A11yMode.Collapsed
	                
	            }
                Label {
                    id: subtitle
                    objectName: "subtitle"
                    visible: text.length > 0
                    multiline: true
                    text: detailsHeader.subtitle
                    textStyle.base: subtitleLightGray.style
                    topMargin: 1
                    bottomMargin: 3
                    accessibilityMode: A11yMode.Collapsed
                    navigation.focusPolicy: detailsHeader.focus_subtitle ? NavigationFocusPolicy.Focusable : NavigationFocusPolicy.NotFocusable
		    navigation.defaultHighlightEnabled: false
                }
                Label {
                    id: description
                    objectName: "description"
                    visible: text.length > 0
                    multiline: true
                    text: detailsHeader.description
                    textStyle.base: subtitleLightGray.style
                    topMargin: 0
                    bottomMargin: 0
                    accessibilityMode: A11yMode.Collapsed
                }
                StarRating {
                    topMargin: 2
                    bottomMargin: 2
                    id: starRating
                    objectName: "starRating"
                    reviewCount: detailsHeader.reviewCount
                    rating: detailsHeader.rating
                    visible: rating > -1
                    verticalAlignment: VerticalAlignment.Center
                    accessibilityMode: A11yMode.Collapsed
                }
                Container {
                    visible: sizeLabel.visible | contentRating.visible
                    topMargin: 6
                    bottomMargin: 10
                    layout: StackLayout {
                        orientation: LayoutOrientation.LeftToRight
                    }
                    Label {
                        verticalAlignment: VerticalAlignment.Center
                        id: sizeLabel
                        objectName: "sizeLabel"
                        text: detailsHeader.sizeLabel
                        textStyle.base: subtitleLightGray.style
                        topMargin: 0
                        bottomMargin: 0
                        visible: text.length > 0
                    }
                    
                    // TODO - accessibility: get the content rating text
                    ImageView {
                        visible: showContentRating
                        verticalAlignment: VerticalAlignment.Center
                        id: contentRating
                        objectName: "contentRating"
                        //imageSource: "asset:///images/tmp/content-rating.png"
                        scalingMethod: ScalingMethod.AspectFit
                        preferredHeight: RatingIconHeight
                        minHeight: RatingIconHeight
                        maxHeight: RatingIconHeight
                        implicitLayoutAnimationsEnabled: false
                        
                        // For now
                        accessibilityMode: A11yMode.Collapsed
                    }

                    ImageView {
                        id: closedCaptionIcon
                        visible: showClosedCaptionIcon
                        objectName: "closedCaptionIcon"
                        scalingMethod: ScalingMethod.AspectFit
                        verticalAlignment: VerticalAlignment.Center
                        preferredHeight: RatingIconHeight
                        minHeight: RatingIconHeight
                        maxHeight: RatingIconHeight
                        leftPadding: 6
                        implicitLayoutAnimationsEnabled: false
                        accessibilityMode: A11yMode.Collapsed
                    }
                }
            }
            Container {
                id: buttonContainer
                objectName: "buttonContainer"
                verticalAlignment: VerticalAlignment.Fill
                implicitLayoutAnimationsEnabled: false
                navigation.defaultHighlightEnabled: false
                topPadding: 12
                layout: StackLayout {
                    orientation: LayoutOrientation.TopToBottom
                }
            }
        }
    }
    
    Divider {
        topMargin: 0
        bottomMargin: 0
    }
}
