import bb.cascades 1.4

Container {
    id: greenButton
    signal clicked()
    property alias text: label.text;
    property string a11yName: label.text;
    //    property ColorPaint textColor: Color.White
    minWidth: 140
    minHeight: 90
    
    implicitLayoutAnimationsEnabled: false
    
    attachedObjects: [
        TextStyleDefinition {
            id: labelStyle
            color: Color.White
            fontSize: FontSize.Small
            fontWeight: FontWeight.W500
            //textAlign: TextAlign.Center
        },
        TextStyleDefinition {
            id: disabledLabelStyle
            color: Color.Gray
            fontSize: FontSize.Small
            fontWeight: FontWeight.W500
        }
    ]
    
    accessibility: CustomA11yObject {
        role: A11yRole.Button
        name: a11yName
 
        ComponentA11ySpecialization {
            onActivationRequested: {
                if (event.type == A11yComponentActivationType.Tap) {
                    greenButton.clicked();
                }
            }
        }
    }
    
    layout: DockLayout {
    }
    onEnabledChanged: {
        if (enabled) {
            label.textStyle.base = labelStyle.style
        } else {
            pressed.visible = false
            label.textStyle.base = disabledLabelStyle.style
        }
    }
    ImageView {
        id: disabled
        implicitLayoutAnimationsEnabled: false
        imageSource: "asset:///images/ButtonGreenDisabled.amd"
        visible: ! greenButton.enabled
        scalingMethod: ScalingMethod.Fill
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        accessibilityMode: A11yMode.Collapsed 
    }
    ImageView {
        id: nonPressed
        implicitLayoutAnimationsEnabled: false
        imageSource: "asset:///images/ButtonGreenEnabled.amd"
        visible: greenButton.enabled
        scalingMethod: ScalingMethod.Fill
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        accessibilityMode: A11yMode.Collapsed 
        navigation.focusPolicy: NavigationFocusPolicy.Focusable

        eventHandlers: [
            TrackpadHandler {
                onTrackpad: {
                    if (event.trackpadEventType == TrackpadEventType.Press) {
                       clicked();
                    }
                }
            }
        ]
    }
    ImageView {
        id: pressed
        implicitLayoutAnimationsEnabled: false
        imageSource: "asset:///images/ButtonGreenEnabledPress.amd"
        visible: false
        scalingMethod: ScalingMethod.Fill
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        accessibilityMode: A11yMode.Collapsed 
        navigation.focusPolicy: NavigationFocusPolicy.Focusable
    }

    Label {
        horizontalAlignment: HorizontalAlignment.Center
        verticalAlignment: VerticalAlignment.Center
        id: label
        textStyle.base: labelStyle.style
        accessibilityMode: A11yMode.Collapsed 
        implicitLayoutAnimationsEnabled: false
        attachedObjects: [
            LayoutUpdateHandler {
                onLayoutFrameChanged: {
                    greenButton.preferredWidth = layoutFrame.width + 70
                    greenButton.minHeight = layoutFrame.height * 2;
                }
            }
        ]
    }
       
    onTouch: {
        if (greenButton.enabled) {
            if (event.isDown()) {
                pressed.visible = true;
            } else if (event.isUp() || event.isCancel()) {
                if (pressed.visible) {
                    pressed.visible = false;
                    clicked();
                }
            }
        }
    }
}
