import bb.cascades 1.2

Container {
    id: item
    objectName: "item"
    property string name;// "Cut the Rope"
    property string subtitle;//: "Some Artist"
    property bool isInstalled: false
    property bool downloading: false
    property variant buttonLink
    signal buttonClicked(variant link)
      
    layout: DockLayout {
    }

    property bool aspectBoxArt: false
    property int iconWidth: StackIconWidth
    property int iconHeight: StackIconWidth
    onAspectBoxArtChanged: {
        if(aspectBoxArt){
            iconHeight = iconWidth * 1.36           
        }else{
            iconHeight = iconWidth;     
        }
    }
    
    Container {
        objectName: "item-" + name + "-" //jwillis
        layout: StackLayout {
            orientation: LayoutOrientation.LeftToRight
        }
        topPadding: 10
        bottomPadding: 10
        
        leftPadding: 20
        rightPadding: 10
      
	    accessibility: CustomA11yObject {
	        role: A11yRole.ListItem
	        name: item.name
	        description: item.subtitle
	        
	        ComponentA11ySpecialization {
	            onActivationRequested: {
	                if (event.type == A11yComponentActivationType.Tap) {
	                   buttonClicked(item.buttonLink);
	                }
	            }	
	        }        
	    }
        
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Top
        Container {
            visible: icon.visible
            preferredWidth: icon.preferredWidth
            verticalAlignment: VerticalAlignment.Center
            accessibilityMode: A11yMode.Collapsed
            
            ImageView {
                visible: false
                id: icon
                objectName: "icon"
                horizontalAlignment: HorizontalAlignment.Center
                verticalAlignment: VerticalAlignment.Center
                imageSource: "asset:///images/loading_placeholder.amd"
                scalingMethod: ScalingMethod.AspectFit
                onImageChanged: {
                    visible = true;
                }
                preferredWidth: StackIconWidth
                preferredHeight: iconHeight
            }
        }
        Container {
            rightMargin: 0
            leftMargin: 10
            verticalAlignment: VerticalAlignment.Center
            horizontalAlignment: HorizontalAlignment.Fill
            accessibilityMode: A11yMode.Collapsed
            
            layoutProperties: StackLayoutProperties {
                spaceQuota: 1
            }
            topPadding: 10
            bottomPadding: 10
            Label {
                text: item.name
                objectName: "name" //jwillis
                textStyle {
                    //color: Color.White
                    base: SystemDefaults.TextStyles.BodyText
                    fontWeight: FontWeight.Normal
                }
                bottomMargin: 0
                topMargin: 0
            }
            Label {
                objectName: "subtitleLabel"
                horizontalAlignment: HorizontalAlignment.Left
                verticalAlignment: VerticalAlignment.Center
                text: item.subtitle
                textStyle {
                    color: Color.create(FontSecondaryColor)
                    base: SystemDefaults.TextStyles.SubtitleText
                }
                bottomMargin: 0
                topMargin: 0
                multiline: true
            }
            Label {
                objectName: "failedLabel"
                horizontalAlignment: HorizontalAlignment.Left
                verticalAlignment: VerticalAlignment.Center
                layoutProperties: StackLayoutProperties {
                    spaceQuota: 1
                }
                text: qsTr("Unsuccessful", "Tells that download was unsuccessful")
                
                accessibility.name: qsTr("Download was unsuccessful")
                
                textStyle {
                    color: Color.Red
                    base: SystemDefaults.TextStyles.SubtitleText
                }
                bottomMargin: 0
                topMargin: 0
                visible: false
            } 
            rightPadding: 20
        }
        
        Container {
            objectName: "download-" + item.name + "-" //jwillis
            verticalAlignment: VerticalAlignment.Fill
            minWidth: StackIconWidth
            preferredWidth: StackIconWidth
            
            layout: DockLayout {
            }
            visible: activityIndicator.visible
            ActivityIndicator {
            	id: activityIndicator
                objectName: "activityIndicator"
                visible: false
                verticalAlignment: VerticalAlignment.Center
                horizontalAlignment: HorizontalAlignment.Center                
            }
        }
        
        Button {
            visible: true
            
            preferredWidth: StackButtonWidth
            id: downloadButton
            objectName: "downloadButton"
            imageSource: "asset:///images/action_icons/ic_download.png"
            //text: "Play"
            verticalAlignment: VerticalAlignment.Center
            horizontalAlignment: HorizontalAlignment.Center
            accessibility.name: downloadButton.text.length > 0 ? downloadButton.text : qsTr("Download")
            accessibility.description: item.name
            onClicked: {
                buttonClicked(item.buttonLink);
            }
        }
        
    }

}
