import bb.cascades 1.4

Container {
    id: track
    objectName: "track"
    
    attachedObjects: [
        TextStyleDefinition {            
            id: subtitleText
            color: Color.create(FontSecondaryColor)
            base: SystemDefaults.TextStyles.SubtitleText            
        }
    ]
    
    property string price;
    property alias title: title.text    
    property alias duration: duration.text
    property alias contentRatingImage: contentRatingImage.imageSource    
    property int currentMSecs: 0
    property int totalMsecs: 1
    property bool previewing: false
    property bool purchased: false

    property bool playing: false
    property bool previewEnabled: false
    
    property alias explicit: contentRatingImage.visible
    property alias albumOnly: albumOnlyLabel.visible

    onPlayingChanged: {
        if(playing){
	        playImage.imageSource =  "asset:///images/action_icons/ic_pause[120x120].png"   
        }else{
            playImage.imageSource = "asset:///images/action_icons/ic_play[120x120].png"
        }
    }
    
    navigation {
        focusPolicy: NavigationFocusPolicy.NotFocusable
        left: playImage
        right: purchaseButton
    }
    
    onPreviewEnabledChanged: {
        if(previewEnabled){
            playImage.opacity = 1.0
        }else{
            playImage.opacity = 0.4
        }
    }

    layout: DockLayout{}
    
    function enablePurchase(purchaseEnabled){
        purchaseButton.enabled = purchaseEnabled;
    }
    
    function onPurchasedChanged(boolPurchased){
        purchased = boolPurchased;
    }

    Container {
        objectName: "item-" + track.title + "-"
        layout: StackLayout {
            orientation: LayoutOrientation.LeftToRight
        }
        
        topPadding: 10
        bottomPadding: 10
        leftPadding: 0
        rightPadding: 10

        Container{
            preferredHeight: TrackListPlayButtonSize
            preferredWidth: TrackListPlayButtonSize
            layout: DockLayout {                
            }
            ActivityIndicator {
                visible: false
                id: playSpinner
                objectName: "playSpinner"
                verticalAlignment: VerticalAlignment.Center
                horizontalAlignment: HorizontalAlignment.Center
            }
	        ImageView {
	            id: playImage
	            objectName: "playImage"
	            imageSource: "asset:///images/action_icons/ic_play[120x120].png"
	            opacity: 0.4
	            overlapTouchPolicy: OverlapTouchPolicy.Allow
	            accessibilityMode: A11yMode.Collapsed
                preferredWidth: TrackListPlayButtonSize
	            scalingMethod: ScalingMethod.AspectFit
                navigation {
                    focusPolicy: NavigationFocusPolicy.Focusable
                }
	        }
	        verticalAlignment: VerticalAlignment.Center
        }    
        
        Container {
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Center
            //preferredHeight: 100
            
            layoutProperties: StackLayoutProperties {
                spaceQuota: 1
            }
 
            accessibility: CustomA11yObject {
		       role: A11yRole.Button
		       name: title.text
		       description: (track.previewing ? ((Math.floor(track.currentMSecs / track.totalMsecs * 100)) + "%") : duration.text) + 
		       				(explicit ? " : " + qsTr("explicit") : "" )
		       
               ComponentA11ySpecialization {
                   id: component
                   onActivationRequested: {
                   }
               }
		    }
            
            Label {
                id: title                            
                //text: "title this long and wraps"// to another line so we can read it."
                multiline: true
                                
                topMargin: 0
                bottomMargin: 10
                verticalAlignment: VerticalAlignment.Top
                textStyle {
                    base: SystemDefaults.TextStyles.BodyText
                }
                accessibilityMode: A11yMode.Collapsed
            }
            ProgressIndicator {
                toValue: track.totalMsecs
                value: track.currentMSecs
                visible: track.previewing
                verticalAlignment: VerticalAlignment.Bottom
                accessibilityMode: A11yMode.Collapsed 
            }
            Container {
                verticalAlignment: VerticalAlignment.Bottom
                visible: ! previewing
                layout: StackLayout {
                    orientation: LayoutOrientation.LeftToRight                    
                }                
                horizontalAlignment: HorizontalAlignment.Fill
                accessibilityMode: A11yMode.Collapsed 

                Label {
                    id: duration
                    //text: "6:00"                    
                    horizontalAlignment: HorizontalAlignment.Left
                    verticalAlignment: VerticalAlignment.Center
                    textStyle.base: subtitleText.style
                    layoutProperties: StackLayoutProperties {
                        spaceQuota: 1
                    }
                }                
                
                // TODO - accessibility: get content rating text 
                ImageView {
                    id: contentRatingImage
                    objectName: "contentRatingImage"
                    //imageSource: "asset:///images/final/ii_rating_explicit.png"
                    horizontalAlignment: HorizontalAlignment.Right
                    verticalAlignment: VerticalAlignment.Center
                    preferredHeight: RatingIconHeight
                    scalingMethod: ScalingMethod.AspectFit
                    visible: false
                    accessibilityMode: A11yMode.Collapsed 
                }                
		        Label{
		            id: albumOnlyLabel
		            objectName: "albumOnlyLabel"
		            visible: false
		            text: qsTr("Album Only")
		            verticalAlignment: VerticalAlignment.Center
		            textStyle.base: subtitleText.style
		        }
		        rightPadding: 20
            }
        }
        
                        
        Container{
            layout: DockLayout {                
            }            
            visible: downloadIndicator.visible | onDeviceIcon.visible
            minWidth: TrackListPlayButtonSize
            verticalAlignment: VerticalAlignment.Fill
            ActivityIndicator {
                id: downloadIndicator
                objectName: "downloadIndicator"
                visible: false
                verticalAlignment: VerticalAlignment.Center
                horizontalAlignment: HorizontalAlignment.Center
            }
            ImageView {
                id: onDeviceIcon
                objectName: "onDeviceIcon"
                imageSource: "asset:///images/action_icons/ic_done.png"
                horizontalAlignment: HorizontalAlignment.Center
                verticalAlignment: VerticalAlignment.Center
                visible: false
                accessibility.name: qsTr("On device.");
            }
        }
        Button {
            id: purchaseButton
            objectName: "purchaseButton"
            text: purchased ? "" : price
            imageSource: purchased ? "asset:///images/action_icons/ic_download.png" : ""
            verticalAlignment: VerticalAlignment.Center
            horizontalAlignment: HorizontalAlignment.Right
            preferredWidth: StackButtonWidth
            accessibilityMode: purchased ? A11yMode.Collapsed : A11yMode.Default
            accessibility.description: title.text
        }
                
    }
}
