import bb.cascades 1.2

Page {
    signal close()
    
    Container {
        opacity: .85
        layout: DockLayout { }
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        
        attachedObjects: [
            LayoutUpdateHandler {
                id: layoutHandler
            }
        ]
        
        ListView {
            id: listView
            property alias layoutFrame: layoutHandler.layoutFrame
            
            objectName: "listView"
            snapMode: SnapMode.LeadingEdge
            flickMode: FlickMode.SingleItem
            stickToEdgePolicy: ListViewStickToEdgePolicy.Beginning
            
            layout: StackListLayout {
                orientation: LayoutOrientation.LeftToRight
            }
            
            attachedObjects: [
                ListScrollStateHandler {
                    onFirstVisibleItemChanged: {
                        currentItemLabel.text = (firstVisibleItem[0] + 1) + '/' + listView.dataModel.childCount(0);
                    }
                }
            ]
            
            listItemComponents: [
            
                ListItemComponent {
                    
                    Container{
                        
                        id: item
                        horizontalAlignment: HorizontalAlignment.Fill
                        verticalAlignment: VerticalAlignment.Fill
                        
                        property int frameWidth: item.ListItem.view.layoutFrame.width
            			property int frameHeight: item.ListItem.view.layoutFrame.height
                        
                        layout: DockLayout { }
                        
                        ImageView {
                            id: img
                            image: ListItemData.image1
                            scalingMethod: ScalingMethod.AspectFit
                            implicitLayoutAnimationsEnabled: false
                            loadEffect: ImageViewLoadEffect.None
                            minWidth: item.frameWidth
                            maxWidth: item.frameWidth
                            minHeight: item.frameHeight
                            maxHeight: item.frameHeight
                        }
                        
                        ImageView {
                            id: backgroundImage
                            image: ListItemData.image2
                            scalingMethod: ScalingMethod.AspectFit
                            loadEffect: ImageViewLoadEffect.None
                            implicitLayoutAnimationsEnabled: false
                           	minWidth: item.frameWidth
                            maxWidth: item.frameWidth
                            minHeight: item.frameHeight
                            maxHeight: item.frameHeight                    
                        }  
                    }
                }
            ]
        }
        
        Container {
            layout: DockLayout { }
            verticalAlignment: VerticalAlignment.Bottom
            horizontalAlignment: HorizontalAlignment.Right
            
            bottomPadding: 20
            rightPadding: 20
            
            Button {
                text: qsTr("Close")
                opacity: .75
                preferredWidth: 125
                horizontalAlignment: HorizontalAlignment.Right
                verticalAlignment: VerticalAlignment.Center
                
                onClicked: {
                    close();
                }
            }
        }
        
        Container {
            opacity: .75
            verticalAlignment: VerticalAlignment.Top
            horizontalAlignment: HorizontalAlignment.Fill
            background: Color.Black
            
            Divider {
                bottomMargin: 5
            }
            
            Container {
                leftPadding: 20
                bottomPadding: 5
                
                Label {
                    id: currentItemLabel
                    topMargin: 5
                    
                    textStyle {
                        color: Color.White
                        fontSize: FontSize.XSmall
                    }
                }
            }
        }
    }
}
